/////////////////////////////////////////////////////////////////////////////
///
/// @file m_lorenz.h
///
/// The time-t map for the Lorenz equations.
/// This map defines a sample time-t map for an ODE.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2014 by Pawel Pilarczyk.
//
// This file is part of my research software package. This is free software:
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this software; see the file "license.txt". If not,
// please, see <https://www.gnu.org/licenses/>.

// Started on June 26, 2012. Last revision: June 26, 2012.


#ifndef _CMGRAPHS_LORENZ_H_
#define _CMGRAPHS_LORENZ_H_


// include local header files
#include "maptype.h"
#include "odetimet.h"


// --------------------------------------------------
// ------------- the Lorenz time-t map --------------
// --------------------------------------------------

/// This class defines the time-t map for the Lorenz equations.
class MapLorenz: public MapOdeTimeT
{
public:
	/// The constructor of a Lorenz map object.
	MapLorenz ();

	/// Returns the name of the map.
	std::string name () const;

}; /* class MapLorenz */

// --------------------------------------------------

inline MapLorenz::MapLorenz (): MapOdeTimeT (
#ifdef _CAPD29_
	"var:x,y,z,pa,pb,pc;"
#else
	"par:pa,pb,pc;var:x,y,z;"
#endif
	"fun:pa*(y-x),(x*(pb-z))-y,(x*y)-(pc*z);",
	2, static_cast<double> (0.05) / 10, 10)
{
	return;
} /* MapLorenz::MapLorenz */

inline std::string MapLorenz::name () const
{
	return std::string ("lorenz");
} /* MapLorenz::name */


#endif // _CMGRAPHS_LORENZ_H_

